==> jupyterlab_mutableai-0.1.14.tar.gz: jupyterlab_mutableai-0.1.14/src/tokens.ts <==
import { IMainMenu } from '@jupyterlab/mainmenu';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { ITranslator } from '@jupyterlab/translation';
import { ContextMenuSvg } from '@jupyterlab/ui-components';
import { CommandRegistry } from '@lumino/commands';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';

import { Token } from '@lumino/coreutils';
import { TransformPollingManager } from './transformPollingManager';

const BASE = 'jupyterlab_mutableai';

export const PLUGIN_ID = `${BASE}:IMutableAI`;

export const IMutableAI = new Token<IMutableAI>(`${BASE}:IMutableAI`);

export interface IMutableAI {
  enable: () => void;
  disable: () => void;
}

export namespace IMutableAI {
  /**
   * MutableAI constructor options
   */
  export interface IOptions {
    /* 
      Jupyter lab core modules translator.
    */
    translator?: ITranslator;

    /* 
      Jupyter lab core modules main menu.
    */
    mainMenu: IMainMenu;
    /* 
      Jupyter lab apps commands registry.
    */
    commands: CommandRegistry;
    /* 
      Jupyter lab apps context menu port.
    */
    contextMenu: ContextMenuSvg;
    /* 
      Jupyter lab factory registry port.
    */
    factory: IFileBrowserFactory;
    /* 
      Jupyter lab Doc registry port.
    */
    docRegistry: DocumentRegistry;

    /**
     * Extension settings getter
     */
    getSettings: () => Promise<ISettingRegistry.ISettings>;

    transformPollingManager: TransformPollingManager;
  }
}

==> jupyterlab_mutableai-0.1.18.tar.gz: jupyterlab_mutableai-0.1.18/src/tokens.ts <==
import { IMainMenu } from '@jupyterlab/mainmenu';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { ITranslator } from '@jupyterlab/translation';
import { ContextMenuSvg } from '@jupyterlab/ui-components';
import { CommandRegistry } from '@lumino/commands';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { JupyterFrontEnd } from '@jupyterlab/application';
import { Token } from '@lumino/coreutils';

const BASE = 'jupyterlab_mutableai';

export const PLUGIN_ID = `${BASE}:IMutableAI`;

export const IMutableAI = new Token<IMutableAI>(`${BASE}:IMutableAI`);

export interface IMutableAI {
  enable: () => void;
  disable: () => void;
}

export namespace IMutableAI {
  /**
   * MutableAI constructor options
   */
  export interface IOptions {
    /* 
      Jupyter lab core modules translator.
    */
    translator?: ITranslator;

    /* 
      Jupyter lab core modules main menu.
    */
    mainMenu: IMainMenu;
    /* 
      Jupyter lab apps commands registry.
    */
    commands: CommandRegistry;
    /* 
      Jupyter lab apps context menu port.
    */
    contextMenu: ContextMenuSvg;
    /* 
      Jupyter lab factory registry port.
    */
    factory: IFileBrowserFactory;
    /* 
      Jupyter lab Doc registry port.
    */
    docRegistry: DocumentRegistry;

    /* 
      Jupyter lab Doc manager port.
    */
    docManager: IDocumentManager;

    /* 
      Jupyter lab app port.
    */
    app: JupyterFrontEnd;

    /**
     * Extension settings getter
     */
    getSettings: () => Promise<ISettingRegistry.ISettings>;
  }
}
